@@ -50,16 +50,6 @@
 #include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-ft-factory.h>
 
-#define SCHEMES           "([a-zA-Z\\+]+)"
-#define INVALID_CHARS     "\\s\"'"
-#define INVALID_CHARS_EXT INVALID_CHARS "\\[\\]<>(){},;:?"
-#define BODY              "([^"INVALID_CHARS"]+)"
-#define BODY_END          "([^"INVALID_CHARS"]*)[^"INVALID_CHARS_EXT".]"
-#define BODY_STRICT       "([^"INVALID_CHARS_EXT"]+)"
-#define URI_REGEX         "("SCHEMES"://"BODY_END")" \
-		          "|((www|ftp)\\."BODY_END")" \
-		          "|((mailto:)?"BODY_STRICT"@"BODY"\\."BODY_END")"
-
 void
 empathy_gtk_init (void)
 {
@@ -75,19 +65,6 @@ empathy_gtk_init (void)
 	initialized = TRUE;
 }
 
-GRegex *
-empathy_uri_regex_dup_singleton (void)
-{
-	static GRegex *uri_regex = NULL;
-
-	/* We intentionally leak the regex so it's not recomputed */
-	if (!uri_regex) {
-		uri_regex = g_regex_new (URI_REGEX, 0, 0, NULL);
-	}
-
-	return g_regex_ref (uri_regex);
-}
-
 static GtkBuilder *
 builder_get_file_valist (const gchar *filename,
 			 const gchar *first_object,
@@ -101,6 +78,7 @@ builder_get_file_valist (const gchar *filename,
 	DEBUG ("Loading file %s", filename);
 
 	gui = gtk_builder_new ();
+	gtk_builder_set_translation_domain (gui, GETTEXT_PACKAGE);
 	if (!gtk_builder_add_from_file (gui, filename, &error)) {
 		g_critical ("GtkBuilder Error (%s): %s",
 				filename, error->message);
@@ -1396,7 +1374,8 @@ empathy_window_iconify (GtkWindow *window, GtkStatusIcon *status_icon)
 
 	XChangeProperty (dpy,
 			 GDK_WINDOW_XID (gdk_window),
-			 gdk_x11_get_xatom_by_name_for_display (gdk_drawable_get_display (gdk_window),
+			 gdk_x11_get_xatom_by_name_for_display (
+				gdk_drawable_get_display (gdk_window),
 			 "_NET_WM_ICON_GEOMETRY"),
 			 XA_CARDINAL, 32, PropModeReplace,
 			 (guchar *)&data, 4);
@@ -1407,11 +1386,10 @@ empathy_window_iconify (GtkWindow *window, GtkStatusIcon *status_icon)
 
 /* Takes care of moving the window to the current workspace. */
 void
-empathy_window_present (GtkWindow *window,
-			gboolean   steal_focus)
+empathy_window_present (GtkWindow *window)
 {
-	guint32 timestamp;
 	GdkWindow *gdk_window;
+	guint32 timestamp;
 
 	g_return_if_fail (GTK_IS_WINDOW (window));
 
@@ -1434,6 +1412,19 @@ empathy_window_present (GtkWindow *window,
 	}
 
 	timestamp = gtk_get_current_event_time ();
+	if (timestamp == 0 && gdk_window != NULL) {
+		GdkEventMask mask;
+
+		/* According to the documentation of gdk_x11_get_server_time
+		 * GDK_PROPERTY_CHANGE_MASK needs to be set in its events otherwise a hang
+		 * can occur. Be sure to at least temporarily set this mask */
+		mask = gdk_window_get_events (gdk_window);
+		gdk_window_set_events (gdk_window,
+			mask | GDK_PROPERTY_CHANGE_MASK);
+		timestamp = gdk_x11_get_server_time (gdk_window);
+		gdk_window_set_events (gdk_window, mask);
+	}
+
 	gtk_window_present_with_time (window, timestamp);
 	gtk_window_set_skip_taskbar_hint (window, FALSE);
 	gtk_window_deiconify (window);
@@ -1554,19 +1545,6 @@ empathy_link_button_new (const gchar *url,
 	return gtk_link_button_new_with_label (url, title);
 }
 
-void
-empathy_toggle_button_set_state_quietly (GtkWidget *widget,
-					GCallback  callback,
-					gpointer   user_data,
-					gboolean   active)
-{
-	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (widget));
-
-	g_signal_handlers_block_by_func (widget, callback, user_data);
-	g_object_set (widget, "active", active, NULL);
-	g_signal_handlers_unblock_by_func (widget, callback, user_data);
-}
-
 void
 empathy_send_file (EmpathyContact *contact, GFile *file)
 {
@@ -1668,6 +1646,9 @@ empathy_send_file_with_file_chooser (EmpathyContact *contact)
 
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (widget), FALSE);
 
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (widget),
+		g_get_home_dir ());
+
 	g_signal_connect (widget, "response",
 			  G_CALLBACK (file_manager_send_file_response_cb),
 			  contact);
@@ -1706,6 +1687,7 @@ void
 empathy_receive_file_with_file_chooser (EmpathyFTHandler *handler)
 {
 	GtkWidget *widget;
+	const gchar *dir;
 
 	widget = gtk_file_chooser_dialog_new (_("Select a destination"),
 					      NULL,
@@ -1720,113 +1702,16 @@ empathy_receive_file_with_file_chooser (EmpathyFTHandler *handler)
 	gtk_file_chooser_set_do_overwrite_confirmation
 		(GTK_FILE_CHOOSER (widget), TRUE);
 
+	dir = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
+	if (dir == NULL)
+		/* Fallback to $HOME if $XDG_DOWNLOAD_DIR is not set */
+		dir = g_get_home_dir ();
+
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (widget), dir);
+
 	g_signal_connect (widget, "response",
 		G_CALLBACK (file_manager_receive_file_response_cb), handler);
 
 	gtk_widget_show (widget);
 }
 
-void
-empathy_string_parser_substr (const gchar *text,
-			      gssize len,
-			      EmpathyStringParser *parsers,
-			      gpointer user_data)
-{
-	if (parsers != NULL && parsers[0].match_func != NULL) {
-		parsers[0].match_func (text, len,
-				       parsers[0].replace_func, parsers + 1,
-				       user_data);
-	}
-}
-
-void
-empathy_string_match_link (const gchar *text,
-			   gssize len,
-			   EmpathyStringReplace replace_func,
-			   EmpathyStringParser *sub_parsers,
-			   gpointer user_data)
-{
-	GRegex     *uri_regex;
-	GMatchInfo *match_info;
-	gboolean    match;
-	gint        last = 0;
-
-	uri_regex = empathy_uri_regex_dup_singleton ();
-	match = g_regex_match_full (uri_regex, text, len, 0, 0, &match_info, NULL);
-	if (match) {
-		gint s = 0, e = 0;
-
-		do {
-			g_match_info_fetch_pos (match_info, 0, &s, &e);
-
-			if (s > last) {
-				/* Append the text between last link (or the
-				 * start of the message) and this link */
-				empathy_string_parser_substr (text + last,
-							      s - last,
-							      sub_parsers,
-							      user_data);
-			}
-
-			replace_func (text + s, e - s, NULL, user_data);
-
-			last = e;
-		} while (g_match_info_next (match_info, NULL));
-	}
-
-	empathy_string_parser_substr (text + last, len - last,
-				      sub_parsers, user_data);
-
-	g_match_info_free (match_info);
-	g_regex_unref (uri_regex);
-}
-
-void
-empathy_string_match_smiley (const gchar *text,
-			     gssize len,
-			     EmpathyStringReplace replace_func,
-			     EmpathyStringParser *sub_parsers,
-			     gpointer user_data)
-{
-	guint last = 0;
-	EmpathySmileyManager *smiley_manager;
-	GSList *hits, *l;
-
-	smiley_manager = empathy_smiley_manager_dup_singleton ();
-	hits = empathy_smiley_manager_parse_len (smiley_manager, text, len);
-
-	for (l = hits; l; l = l->next) {
-		EmpathySmileyHit *hit = l->data;
-
-		if (hit->start > last) {
-			/* Append the text between last smiley (or the
-			 * start of the message) and this smiley */
-			empathy_string_parser_substr (text + last,
-						      hit->start - last,
-						      sub_parsers, user_data);
-		}
-
-		replace_func (text + hit->start, hit->end - hit->start,
-			      hit, user_data);
-
-		last = hit->end;
-
-		empathy_smiley_hit_free (hit);
-	}
-	g_slist_free (hits);
-	g_object_unref (smiley_manager);
-
-	empathy_string_parser_substr (text + last, len - last,
-				      sub_parsers, user_data);
-}
-
-void
-empathy_string_match_all (const gchar *text,
-			  gssize len,
-			  EmpathyStringReplace replace_func,
-			  EmpathyStringParser *sub_parsers,
-			  gpointer user_data)
-{
-	replace_func (text, len, NULL, user_data);
-}
-
